Documentation
¶
Index ¶
Constants ¶
const ( EblockPrefix = "eb:" EntryPreix = "et:" )
Variables ¶
This section is empty.
Functions ¶
func NewEntrySnapshot ¶
func NewEntrySnapshot(dir string) *entrySnapshot
Types ¶
type BalanceSnapshot ¶
func (*BalanceSnapshot) Process ¶
func (bs *BalanceSnapshot) Process(log *logrus.Logger, db tools.Fetcher, height uint32, diagnostic bool) error
Process will process the height specified and load the balance changes into the memory maps. We pass the entire database to allow this function to do w/e it needs. Passing the height in explicitly just ensures we are loading blocks sequentially
type Snapshotter ¶
type Snapshotter struct {
// contains filtered or unexported fields
}
func New ¶
func New(cfg Config) (*Snapshotter, error)
func (*Snapshotter) Done ¶
func (s *Snapshotter) Done() error
Done is called to close up the snapshots
func (*Snapshotter) Dump ¶
func (s *Snapshotter) Dump() error
func (*Snapshotter) WalkDB ¶
func (s *Snapshotter) WalkDB() error
Click to show internal directories.
Click to hide internal directories.